@@ -10,7 +10,7 @@ use HTML::Parser;
 use HTML::Form;
 use Digest::MD5();
 
-our $VERSION = '7.09';
+our $VERSION = '7.10';
 
 # $Id: $
 # $Log: LaPoste.pm,v $
@@ -135,11 +135,6 @@ sub _login {
     $form->value(password => $password);
 
     push @{$self->{ua}->requests_redirectable}, 'POST';
-
-    $self->{feedback}->("wait (faking user filling the password)") if $self->{feedback};
-    sleep 1; # wait otherwise we will get blocked (?)
-    $self->{feedback}->("login") if $self->{feedback};
-
     $response = $self->{ua}->request($form->click);
     $response->is_success or die "login failed\n" . $response->error_as_HTML;
 
@@ -147,16 +142,7 @@ sub _login {
 
     $response = _handle_javascript_redirects($self, $response);
 
-    my $try = 1;
-  retry:
     $self->{accounts} = [ _list_accounts($self, $response) ];
-    @{$self->{accounts}} or do {
-	$try == 1 or die "no valid accounts\n";
-	$try++;
-	$response = $self->{ua}->request(HTTP::Request->new(GET => $response->base));
-	$self->{feedback}->("list accounts $try") if $self->{feedback};
-	goto retry;
-    }
 }
 
 sub _handle_javascript_redirects {
@@ -275,7 +261,7 @@ sub new {
     exists $self->{password} or croak "Must provide a password";
     exists $self->{username} or croak "Must provide a username";
 
-    $self->{ua} ||= LWP::UserAgent->new;
+    $self->{ua} ||= LWP::UserAgent->new(agent => 'Mozilla');
 
     _login($self);
     $self;
